@@ -174,7 +174,7 @@ class MACNN(nn.Module):    # 定义注意力卷积模型
         x = self.fc(x)
         return x
 
-def WavPro(wav_data):
+def WavPro(wav_data,path):
     model = MACNN(4, 32)  # 调用模型
     model.load_state_dict(torch.load(path))  # 加载模型
     model = model.cuda()  # u、cuda加速
